@@ -4,13 +4,13 @@ use warnings;
 
 package Gentoo::VDB::Portage;
 
-our $VERSION = '0.001001';
+our $VERSION = '0.001002';
 
 # ABSTRACT: VDB Query Implementation for Portage/Emerge
 
 # AUTHORITY
 
-use Path::Tiny qw( path );
+use Path::Tiny 0.048 qw( path );  # subsumes
 
 sub new {
     my ( $class, @args ) = @_;
